@@ -1,7 +1,7 @@
 from torch.nn.parameter import Parameter
 import numpy as np
 import torch
-import torch.nn as nn
+from torch import nn
 
 class convert_for_training:
   def convert_train(self,om,trainfunc,data,params,factor):
